@@ -16,11 +16,11 @@ Pod::Query - Query pod documents
 
 =head1 VERSION
 
-Version 0.27
+Version 0.29
 
 =cut
 
-our $VERSION                   = '0.27';
+our $VERSION                   = '0.29';
 our $DEBUG_LOL_DUMP            = 0;
 our $DEBUG_STRUCT_OVER         = 0;
 our $DEBUG_TREE                = 0;
@@ -108,12 +108,14 @@ Flag to indicate if the class is really a path to the file.
 
 =cut
 
-_has qw(
-  path
-  lol
-  tree
-  class_is_path
-);
+sub import {
+    _has qw(
+      path
+      lol
+      tree
+      class_is_path
+    );
+}
 
 #
 # Debug
@@ -123,10 +125,10 @@ sub _dumper {
     require Data::Dumper;
     my $data = Data::Dumper
       ->new( [@_] )
-      ->Terse( 1 )
       ->Indent( 1 )
       ->Sortkeys( 1 )
-      ->Purity( 1 )
+      ->Terse( 1 )
+      ->Useqq( 1 )
       ->Dump;
     return $data if defined wantarray;
     say $data;
